@@ -21,7 +21,7 @@ checkX13binary <- function(fail.unsupported = FALSE, verbose = TRUE){
       stop("X-13 binary file not found")
     }
 
-    tdir <- tempdir()
+    dir.create(tdir <- tempfile())
     file.copy(system.file("testdata", "Testairline.spc", package="x13binary"), tdir)
     if (.Platform$OS.type == "windows") {
 
@@ -86,6 +86,7 @@ checkX13binary <- function(fail.unsupported = FALSE, verbose = TRUE){
       "\nFor this platform, there are currently no binaries of X-13ARIMA-SEATS.")
     return(invisible(FALSE))
   }
+  unlink(tdir, recursive=TRUE, force=TRUE)
 
   invisible(TRUE)
 }
